@@ -41,7 +41,11 @@ enum
     ERROR_DEL_FILE,
     ERROR_TUNE,
     ERROR_NO_DIFF,
+    ERROR_MEMORY,
+    ERROR_NETWORK,
     ERROR_CAM,
+    ERROR_GENERIC,
+    ERROR_NO_CAM_INIT,
   };
 
 #endif
